/**************************************************************** 
 * Description: 洛谷P2168
 使用优先队列（最小堆）来存储单词的出现次数和对应的编码长度。
 每次从队列中取出 k 个元素，计算它们的总权重（出现次数之和）和最大高度（编码长度），
 然后将这个总权重和高度+1的新节点再次加入队列。重复上述过程，直到队列中的元素少于 k 个。
 这个算法的核心是构建一个最小权重树，使用优先队列（最小堆）来有效地选择最小权重的节点，
 并且在树的构建过程中确保没有两个字符串是彼此的前缀。这样的算法能够确保在满足前缀条件的同时，使得整个文本的编码长度最小化。
 * Author: Alex Li
 * Date: 2024-01-28 21:44:00
 * LastEditTime: 2024-01-28 22:20:45
****************************************************************/

#include<cstdio>
#include<cstring>
#include<queue>
#include<algorithm>
using namespace std;

typedef long long ll;
struct node{
    ll w,h;  //w为重量，h为高度
    node(){w=0,h=0;}
    node(ll w,ll h):w(w),h(h){}
    bool operator <(const node &a)const{return a.w==w?h>a.h:w>a.w;}
};
ll ans;
priority_queue<node>  q;  //优先队列
int main()
{
    ll n,k;ans=0;scanf("%lld%lld",&n,&k);
    for(int i=1;i<=n;i++){
        ll w;scanf("%lld",&w);
        q.push(node(w,1));  //将每个单词（权重和初始高度）加入优先队列
    }

    // 如果队列大小不满足(k-1)的倍数，则添加权重为0的节点以满足条件
    while((q.size()-1)%(k-1)!=0)q.push(node(0,1));

    // 当队列中元素数量大于等于k时循环
    while(q.size()>=k)
    {
        ll h=-1;ll w=0;
        for(int i=1;i<=k;++i)
        {
            node t=q.top();q.pop(); //取出k个最小元素
            h=max(h,t.h);  // 更新高度
            w+=t.w; // 累加权重
        }
        ans+=w;  //更新答案
        q.push(node(w,h+1)); //// 将新节点加入队列
    }
      //输出总长度和最长字符串的最短长度
    printf("%lld\n%lld\n",ans,q.top().h-1);
    return 0;
}